fern-proxy 0.1.0

Cloud Native high performance security and privacy SQL proxy.
fern-proxy-0.1.0 is not a library.

Cloud Native high performance security and privacy SQL proxy

Work in progress... ⏳

For the time being, development in Fern proxy focuses on implementing core features to support and provide value in a PostgreSQL datastore scenario. Wire protocols and abstractions allowing other datastores will come later. Same goes for deployment and optimizations leveraging DaemonSets and eBPF.

Feel free to contribute! 👍